/***********************************************************************************************************************************
Archive Get Command
***********************************************************************************************************************************/
#ifndef COMMAND_ARCHIVE_GET_GET_H
#define COMMAND_ARCHIVE_GET_GET_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
int cmdArchiveGet(void);

#endif
